#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_INTERLEAVE_ODD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_INTERLEAVE_ODD_HPP_INCLUDED

#include <boost/simd/swar/include/functions/scalar/interleave_odd.hpp>

#endif
